Package: remstats
Type: Package
Title: Computes Statistics for Relational Event History Data
Version: 4.0.0
Date: 2026-05-07
Authors@R: 
    c(
        person(
            given = "Giuseppe",
            family = "Arena",
            role = "aut",
            email = "g.arena@uva.nl",
            comment = c(ORCID = "0000-0001-5204-3326")),
        person(
            given = "Marlyne",
            family = "Meijerink-Bosman",
            role = "aut"),
        person(
            given = "Joris",
            family = "Mulder",
            role = c("aut", "cre"),
            email = "j.mulder3@tilburguniversity.edu"),
        person(
            given = "Diana",
            family = "Karimova",
            role = "ctb"),
        person(
            given = "Rumana",
            family = "Lakdawala",
            role = "ctb"),
        person(
            given = "Mahdi",
            family = "Shafiee Kamalabad",
            role = "ctb"),
        person(
            given = "Fabio",
            family = "Generoso Vieira",
            role = "ctb"),
        person(
            given = "Roger",
            family = "Leenders",
            role = "ctb",
            email = "r.t.a.j.leenders@tilburguniversity.edu")
    )
Maintainer: Joris Mulder <j.mulder3@tilburguniversity.edu>
Description: Computes a variety of statistics for relational event models (Meijerink et al., 2023, <doi:10.3758/s13428-022-01821-8>). Relational event models enable researchers to investigate exogenous and endogenous factors, and interactions, influencing the evolution of a time-ordered sequence of events. These models are categorized into tie-oriented models (Butts, C., 2008, <doi:10.1111/j.1467-9531.2008.00203.x>), where the probability of a dyad interacting next is modeled in a single step, and actor-oriented models (Stadtfeld, C., & Block, P., 2017, <doi:10.15195/v4.a14>), which first model the probability of a sender initiating an interaction and subsequently the probability of the sender's choice of receiver. The package is designed to compute a variety of statistics that summarize exogenous and endogenous influences on the event stream for both types of models.  
License: MIT + file LICENSE
URL: https://tilburgnetworkgroup.github.io/remstats/
BugReports: https://github.com/TilburgNetworkGroup/remstats/issues
LazyData: true
Encoding: UTF-8
RoxygenNote: 7.3.3
Depends: R (>= 4.0.0)
Imports: Rcpp (>= 1.0.8.3), remify (>= 4.0.0), stats, graphics,
        grDevices
LinkingTo: Rcpp, RcppArmadillo, RcppProgress
Suggests: tinytest, knitr, rmarkdown
VignetteBuilder: knitr
LazyDataCompression: gzip
NeedsCompilation: yes
Packaged: 2026-05-07 14:04:19 UTC; jorismulder
Author: Giuseppe Arena [aut] (ORCID: <https://orcid.org/0000-0001-5204-3326>),
  Marlyne Meijerink-Bosman [aut],
  Joris Mulder [aut, cre],
  Diana Karimova [ctb],
  Rumana Lakdawala [ctb],
  Mahdi Shafiee Kamalabad [ctb],
  Fabio Generoso Vieira [ctb],
  Roger Leenders [ctb]
Repository: CRAN
Date/Publication: 2026-05-09 14:41:20 UTC
Built: R 4.5.2; aarch64-apple-darwin20; 2026-05-09 18:35:29 UTC; unix
Archs: remstats.so.dSYM
