# Generated by roxygen2: do not edit by hand

S3method(boxplot,aomstats)
S3method(boxplot,tomstats)
S3method(plot,aomstats)
S3method(plot,tomstats)
S3method(print,remstats)
S3method(print,tomstats_sampled)
S3method(stack_stats,aomstats)
S3method(stack_stats,tomstats)
S3method(stack_stats,tomstats_sampled)
S3method(summary,remstats)
export(FEtype)
export(actor_effects)
export(aomstats)
export(average)
export(bind_remstats)
export(degreeDiff)
export(degreeMax)
export(degreeMin)
export(difference)
export(dyad)
export(event)
export(indegreeReceiver)
export(indegreeSender)
export(inertia)
export(isp)
export(itp)
export(maximum)
export(minimum)
export(osp)
export(otp)
export(outdegreeReceiver)
export(outdegreeSender)
export(psABA)
export(psABAB)
export(psABAY)
export(psABB)
export(psABBA)
export(psABBY)
export(psABX)
export(psABXA)
export(psABXB)
export(psABXY)
export(receive)
export(recencyContinue)
export(recencyReceiveReceiver)
export(recencyReceiveSender)
export(recencySendReceiver)
export(recencySendSender)
export(reciprocity)
export(remstats)
export(rrankReceive)
export(rrankSend)
export(same)
export(send)
export(sp)
export(spUnique)
export(stack_stats)
export(tie)
export(tie_effects)
export(tomstats)
export(totaldegreeDyad)
export(totaldegreeReceiver)
export(totaldegreeSender)
export(userStat)
importFrom(Rcpp,sourceCpp)
importFrom(grDevices,rainbow)
importFrom(graphics,axis)
importFrom(graphics,boxplot)
importFrom(graphics,bxp)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(remify,remify)
importFrom(stats,IQR)
importFrom(stats,quantile)
importFrom(stats,setNames)
useDynLib(remstats, .registration = TRUE)
