REMSTATS - a Remote Statistics System (version 1.0.13a)

A system of programs to: 
	- gather data from remote machines,
	- store and maintain the data for long periods,
	- produce graphs and web-pages tieing them together
	- monitor the data for anomalous behaviours and issue alerts

Remstats' major difference from both orca and cricket is that I wanted lots
of graphs on the screen.  I'm not monitoring over a dialup, though it's not too
bad over 64K ISDN; I wanted to see lots of graphs together so I could correlate
things happening on one graph with other graphs.  It's already been useful
to me.  Please let me know if you find it useful.

MRTG and NOCOL provided the inspiration.  Rrdtool provided the guts.
Perl provided the platform.  Various other people provided bug-reports and 
suggestions and I wrote some glue to make it hang together.

Read RELEASENOTES for upgrade instructions, and new features. 
Read INSTALL for installations instructions.
Read ChangeLog for more detailed descriptions of what has changed.
Read BUGS for known problems that haven't been fixed yet.
Read FAQ for Frequently Asked Questions with their answers.
Read TODO for my list of things that would be nice to have in remstats.

Source available at http://remstats.sourceforge.net/release//index.html

Wed May 28 11:54:43 EDT 2003 Thomas Erskine <terskine@users.sourceforge.net>
