=cut

TITLE=availability-report.cgi
DESCRIPTION=show availability of various RRD variables
KEYWORDS=availability-report.cgi
DOCTOP=index
DOCPREV=alert-cgi
DOCNEXT=dataimage-cgi

=pod

=head1 availability-report.cgi

The C<availability-report.cgi|availability-report-cgi> calls L<availability-report> to produce
a report of "availability" according to the definitions in the
L<availability|configfile-availability> config-file.
