=cut

TITLE=availability-report
DESCRIPTION=show availability of various RRD variables
KEYWORDS=availability-report
DOCTOP=index
DOCPREV=alerter
DOCNEXT=convert-config-links

=pod

=head1 availability-report

=head2 Usage:

=exec ../availability-report -h 2>&1

=head2 Description:

This is mainly intended to be called from 
L<availability-report.cgi|availability-report-cgi>.  It provided
a report on "availability" of specified RRD variables, by default, all
that have definitions in the L<availability|configfile-availability>
config-file.  Exactly what it means for a variable to be "available"
is up to you.  It's intended to give some measure of when a host or
service isn't useable, so, e.g. the default definition of availability
for the C<ping> RRD variable C<rcvd> (number of ping responses received)
is:

	ping rcvd MINIMUM > 0

In english, the C<rcvd> variable is considered unavailable if:

	- it is less than or equal to zero (I.E. it didn't respond to ping)
	- there is no data available for that time period

B<N.B.:> The interaction between rrd archive consolidation and the xff value,
(see rrdcreate), can result in longer periods of unavailability or conversely,
masking periods of unavailability.  Choose the consolidation function carefully
to make sure you're getting the best data possible.
