
=for html
<P>
<HR>
[<A CLASS="BUT" HREF="@@HTMLURL@@/release/index.html">Top</a>]
[<A CLASS="BUT" HREF="http://remstats.sourceworks.com:1954/">Remstats</a>]
[<A CLASS="BUT" HREF="http://www.sourceworks.com/">SourceWorks</a>]
[<A CLASS="BUT" HREF="http://ee-staff.ethz.ch/~oetiker/webtools/rrdtool">RRDtool</a>]
[<A CLASS="BUT" HREF="http://sourceforge.net/projects/remstats">SourceForge</a>]
<BR><FONT SIZE="-1">Last updated @@DATE@@ by <A HREF="mailto:@@AUTHOR@@">&lt;@@AUTHOR@@&gt;</A></FONT>.
</TD></TR>
</TABLE>
</BODY></HTML>

=for text

=for text
------------------------------------------------------------------
Last updated @@DATE@@ by <@@AUTHOR@@>.

