=for html
@@DOCTYPE@@
<HTML>
<!--
$Id: HEADER.pod,v 1.8 2002/05/01 05:05:43 remstats Exp $
Copyright 1999, 2000, 2001, 2002 (c) Thomas Erskine.
See the COPYRIGHT file with the distribution.
-->
<HEAD>
	<TITLE>remstats - @@TITLE@@</TITLE>
	<META HTTP-EQUIV="description"
		CONTENT="remstats - @@DESCRIPTION@@">
	<META HTTP-EQUIV="keywords"
		CONTENT="remstats,rrdtool,@@KEYWORDS@@">
	<LINK REV="MADE" HREF="mailto:@@AUTHOR@@">
	<LINK REL="STYLESHEET" HREF="@@HTMLURL@@/default.css" TYPE="text/css">
</HEAD>
<BODY BGCOLOR="white">
<TABLE BORDER=0>
<TR WIDTH="20%">
<TD ALIGN="LEFT" VALIGN="TOP" COLOR="#000000" BGCOLOR="#5F9FFF" LINKCOLOR="#FFFFFF" VISITEDCOLOR="#FF9F9F">
<P ALIGN="CENTER"><BR><A HREF="@@SRCURL@@index.html"><IMG SRC="@@HTMLURL@@/IMAGES/remstats.png" BORDER=0 ALT="Remstats Home"></A><P>
<BR>
<FONT SIZE="-1">
