=cut

TITLE=alert-yahoo
DESCRIPTION=sends an alert message via yahoo instant messenger
KEYWORDS=alert-yahoo
DOCTOP=index
DOCPREV=alert-winpopup
DOCNEXT=alert-yahoo

=pod

=head1 alert-yahoo - an alert sending script

This is a simple script intended to be run by the L<alerter>.  
Like all alert-senders, it takes one argument on the command-line:
the "address" to send the alert to.  The text of the alert is
fed to this script on stdin.  

It sends the alert to "address", in this case a yahoo ID.
