=cut

TITLE=alert-syslog
DESCRIPTION=sends an alert message via syslog
KEYWORDS=alert-syslog
DOCTOP=index
DOCPREV=alert-winpopup
DOCNEXT=alert-yahoo

=pod

=head1 alert-syslog - an alert sending script

=exec ../alert-syslog -h 2>&1

This simply raises an alert by writing it to syslog.  Useful if you want to
keep everything in syslog.
