</FONT>
<P><HR>
&nbsp;&nbsp;<A HREF="@@HTMLURL@@/quick-index.cgi">Live Data</A>
<P>
&nbsp;&nbsp;<FONT SIZE="-1">Remstats was written by<BR>
&nbsp;&nbsp;<A HREF="mailto:@@AUTHOR@@">Thomas Erskine</A> at the<BR>
&nbsp;&nbsp;<A HREF="http://www.crc.ca/">CRC</a> in Canada and now<BR>
&nbsp;&nbsp;at <A HREF="http://www.sourceworks.com/">SourceWorks</A>.
</FONT>
</TD><TD WIDTH="5"></TD>
<TD ALIGN="LEFT" VALIGN="TOP">
[<A CLASS="BUT" HREF="@@DOCTOP@@.html">Top</A>]
[<A CLASS="BUT" HREF="@@DOCPREV@@.html">Prev</A>]
[<A CLASS="BUT" HREF="@@DOCNEXT@@.html">Next</A>]
<HR>

