=cut

TITLE=alert-winpopup
DESCRIPTION=sends an alert message via a Windows popup message
KEYWORDS=alert-winpopup
DOCTOP=index
DOCPREV=alert-syslog
DOCNEXT=alert-yahoo

=pod

=head1 alert-winpopup - an alert sending script

This is a simple script intended to be run by the L<alerter>.  
Like all alert-senders, it takes one argument on the command-line:
the "address" to send the alert to.  The text of the alert is
fed to this script on stdin.  

It sends the alert to use "address", in this case a windows NetBIOS
machine name, via a Windows popup message.
