=cut

TITLE=alert-email
DESCRIPTION=sends email to notify someone of an alert
KEYWORDS=alert-email
DOCTOP=index
DOCPREV=alerter
DOCNEXT=alert-syslog

=pod

=head1 alert-email - an alert sending script

This is a simple script intended to be run by the L<alerter>.  
Like all alert-senders, it takes one argument on the command-line:
the "address" to send the alert to.  The text of the alert is
fed to this script on stdin.  

It sends the alert text to "address" via email, by invoking sendmail,
though there's no reason that it couldn't be re-written to do an SMTP
injection directly if some-one wanted to.  With no error-checking, it
could be re-written as:

	#!/bin/sh
	/usr/lib/sendmail "$1"


