=cut

TITLE=alert.cgi
DESCRIPTION=alert reporting and updating
KEYWORDS=alert.cgi
DOCTOP=index
DOCPREV=cgis
DOCNEXT=availability-report-cgi

=pod

=head1 alert.cgi - Alert Reporting and Updating

This CGI script will generate the Alert Report and also let you modify it.
You can turn alerts off for a specific line (by checking the C<quench>
check-box).  You can also attach comments to a specific alert, for example
to let other people know that you're already working on it, or when a
service will be available again.

