% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/effects.R
\name{spUnique}
\alias{spUnique}
\title{spUnique}
\usage{
spUnique()
}
\value{
Warning.
}
\description{
Deprecated. Use \code{\link{sp}}.
}
